@@ -1,7 +1,6 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.transaction import Transaction
 from trytond.pool import Pool
 
 
@@ -23,8 +22,8 @@ class Cron(ModelSQL, ModelView):
             })
             super(Cron, self)._callback(cron)
         user_obj.write(cron.user.id, {
-            'company': False,
-            'main_company': False,
+            'company': None,
+            'main_company': None,
         })
 
     def default_companies(self):
@@ -39,8 +38,8 @@ class CronCompany(ModelSQL):
     _name = 'ir.cron-company.company'
     _table = 'cron_company_rel'
     cron = fields.Many2One('ir.cron', 'Cron', ondelete='CASCADE',
-            required=True, select=1)
+            required=True, select=True)
     company = fields.Many2One('company.company', 'Company', ondelete='CASCADE',
-            required=True, select=1)
+            required=True, select=True)
 
 CronCompany()
